summaryrefslogtreecommitdiffstats
path: root/korganizer/timelabels.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
commitf4fae92b6768541e2952173c3d4b09040f95bf7e (patch)
treed8c5d93232235cd635f3310b4d95490df181ba2d /korganizer/timelabels.cpp
parent125c0a08265b75a133644d3b55f47e37c919f45d (diff)
downloadtdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.tar.gz
tdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.zip
Moved kpilot from kdepim to applications, as the core Trinity libraries should not contain hardware-dependent software
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1221127 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'korganizer/timelabels.cpp')
-rw-r--r--korganizer/timelabels.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/korganizer/timelabels.cpp b/korganizer/timelabels.cpp
index 81b53c1f6..53bc34588 100644
--- a/korganizer/timelabels.cpp
+++ b/korganizer/timelabels.cpp
@@ -197,7 +197,7 @@ void TimeLabels::updateConfig()
sFont.setPointSize( sFont.pointSize()/2 );
TQFontMetrics fmS( sFont );
mMiniWidth += fmS.width( test ) + frameWidth()*2+4 ;
- // update geometry restrictions based on new settings
+ // update tqgeometry restrictions based on new settings
setFixedWidth( mMiniWidth );
// update HourSize
@@ -237,14 +237,14 @@ void TimeLabels::setAgenda( KOAgenda* agenda )
}
/** This is called in response to repaint() */
void TimeLabels::paintEvent(TQPaintEvent*)
{
// kdDebug(5850) << "paintevent..." << endl;
// this is another hack!
// TQPainter painter(this);
//TQString c
- repaintContents(contentsX(), contentsY(), visibleWidth(), visibleHeight());
+ tqrepaintContents(contentsX(), contentsY(), visibleWidth(), visibleHeight());
}
#include "timelabels.moc"
@@ -237,14 +237,14 @@ void TimeLabels::setAgenda( KOAgenda* agenda )
}
-/** This is called in response to repaint() */
+/** This is called in response to tqrepaint() */
void TimeLabels::paintEvent(TQPaintEvent*)
{